==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetInteractionsResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetInteractionsResult]
(
	@VCC				VARCHAR(50),
	@ProcessId			VARCHAR(50),
	@Channels			VARCHAR(100)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS UN QUERY DEPENDIENDO DEL CANAL
	IF @Channels = 'CALL' 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(CALL)
		SELECT 'CALL'																'interactionType', 
				COUNT(DISTINCT CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]))		'quantity',
				ISNULL(SUM(A.[DurationTime]), 0)									'timeQuantity',
				COUNT(DISTINCT A.[ID])												'totalSyncInteractions'
				--COUNT(DISTINCT A.[ID])												'timeQuantity'
			FROM [dbo].[Process] P (NOLOCK)
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
				ON PA.[ProcessId] = P.[Name]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE P.[VCC] = @VCC
				AND P.[Name] = @ProcessId
				AND A.[ID] IS NOT NULL

	END
	ELSE 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(OTROS CANALES)
		SELECT PAI.[InteractionType]												'interactionType',
				COUNT(DISTINCT CONCAT(PAI.[InteractionId], PAI.[EndDate]))			'totalInteractionDetails',
				COUNT(DISTINCT PAI.[InteractionId])									'totalInteractions'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK) 
			WHERE PAI.[VCC] = @VCC 
				AND PAI.[ProcessId] = @ProcessId
				AND PAI.[InteractionType] IN (SELECT VALUE FROM [dbo].[split](@Channels, ','))
			GROUP BY PAI.[InteractionType]
	END

	/* -- ESTA FUNCION RETORNA SOLO EL TOTAL Y TIEMPO DE LOS AUDIOS QUE NO HAN SIDO TRANSCRITOS
	SELECT
		COUNT(PA.[AudioId])						'interactionsTotal',
		ISNULL(SUM(A.[DurationTime]), 0)		'timeInSeconds'
	FROM ProcessAudio PA (NOLOCK)
	INNER JOIN Audio A (NOLOCK) 
		ON CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) 
			AND PA.[VCC] = A.[VCC]
	WHERE
		PA.[VCC] = @VCC
		AND [ProcessId] = @ProcessId
		AND A.[IsTranscribed] IS NULL
	*/
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetInteractionsResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetInteractionsResult]
(
	@VCC				VARCHAR(50),
	@ProcessId			VARCHAR(50),
	@Channels			VARCHAR(100)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS UN QUERY DEPENDIENDO DEL CANAL
	IF @Channels = 'CALL' 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(CALL)
		SELECT 'CALL'																'interactionType', 
				COUNT(DISTINCT CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]))		'quantity',
				ISNULL(SUM(A.[DurationTime]), 0)									'timeQuantity',
				COUNT(DISTINCT A.[ID])												'totalSyncInteractions',
				SUM(
					CASE WHEN A.[IsCancel] = 1 THEN A.[DurationTime] ELSE 0 END
				)																	'alreadyTranscribedTime',
				SUM(
					CASE WHEN A.[IsProcess] IS NULL THEN A.[DurationTime] ELSE 0 END 
				)																	'notTranscribedDurationTime',
				SUM(
					CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL)
					THEN A.[DurationTime] ELSE 0 END
				)																	'inProcessTime',
				SUM(
					CASE WHEN A.[IsCancel] = 1 THEN A.[DurationTime] ELSE 0 END
				)																	'cancelledTime'
				--COUNT(DISTINCT A.[ID])												'timeQuantity'
			FROM [dbo].[Process] P (NOLOCK)
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
				ON PA.[ProcessId] = P.[Name]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE P.[VCC] = @VCC
				AND P.[Name] = @ProcessId
				AND A.[ID] IS NOT NULL

	END
	ELSE 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(OTROS CANALES)
		SELECT PAI.[InteractionType]												'interactionType',
				COUNT(DISTINCT CONCAT(PAI.[InteractionId], PAI.[EndDate]))			'totalInteractionDetails',
				COUNT(DISTINCT PAI.[InteractionId])									'totalInteractions'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK) 
			WHERE PAI.[VCC] = @VCC 
				AND PAI.[ProcessId] = @ProcessId
				AND PAI.[InteractionType] IN (SELECT VALUE FROM [dbo].[split](@Channels, ','))
			GROUP BY PAI.[InteractionType]
	END

	/* -- ESTA FUNCION RETORNA SOLO EL TOTAL Y TIEMPO DE LOS AUDIOS QUE NO HAN SIDO TRANSCRITOS
	SELECT
		COUNT(PA.[AudioId])						'interactionsTotal',
		ISNULL(SUM(A.[DurationTime]), 0)		'timeInSeconds'
	FROM ProcessAudio PA (NOLOCK)
	INNER JOIN Audio A (NOLOCK) 
		ON CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) 
			AND PA.[VCC] = A.[VCC]
	WHERE
		PA.[VCC] = @VCC
		AND [ProcessId] = @ProcessId
		AND A.[IsTranscribed] IS NULL
	*/
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
